/**
 * Copyright (c) 2013 RCP Vision (http://www.rcp-vision.com) and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 * Lorenzo Bettini - initial API and implementation
 */
package org.eclipse.emf.parsley.generator.common;

import org.eclipse.xtend2.lib.StringConcatenation;

/**
 * @author Lorenzo Bettini - initial API and implementation
 */
@SuppressWarnings("all")
public class EmfParsleyProjectFilesGenerator {
  public String moduleFileName(final String projectName) {
    return EmfParsleyProjectFilesGeneratorUtil.buildClassNameFromProject(projectName);
  }

  public CharSequence activatorName(final String projectName) {
    StringConcatenation _builder = new StringConcatenation();
    String _buildClassNameFromProject = EmfParsleyProjectFilesGeneratorUtil.buildClassNameFromProject(projectName);
    _builder.append(_buildClassNameFromProject);
    _builder.append("Activator");
    return _builder;
  }

  public CharSequence extFactoryName(final String projectName) {
    StringConcatenation _builder = new StringConcatenation();
    String _buildClassNameFromProject = EmfParsleyProjectFilesGeneratorUtil.buildClassNameFromProject(projectName);
    _builder.append(_buildClassNameFromProject);
    _builder.append("ExecutableExtensionFactory");
    return _builder;
  }

  public CharSequence generateActivator(final String projectName) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("package ");
    _builder.append(projectName);
    _builder.append(";");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("import org.osgi.framework.BundleContext;");
    _builder.newLine();
    _builder.append("import org.eclipse.ui.plugin.AbstractUIPlugin;");
    _builder.newLine();
    _builder.newLine();
    _builder.append("/**");
    _builder.newLine();
    _builder.append(" ");
    _builder.append("* The activator class controls the plug-in life cycle");
    _builder.newLine();
    _builder.append(" ");
    _builder.append("*/");
    _builder.newLine();
    _builder.append("public class ");
    CharSequence _activatorName = this.activatorName(projectName);
    _builder.append(_activatorName);
    _builder.append(" extends AbstractUIPlugin {");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("// The plug-in ID");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("public static final String PLUGIN_ID = \"");
    _builder.append(projectName, "\t");
    _builder.append("\"; //$NON-NLS-1$");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("// The shared instance");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("private static ");
    CharSequence _activatorName_1 = this.activatorName(projectName);
    _builder.append(_activatorName_1, "\t");
    _builder.append(" plugin;");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("public ");
    CharSequence _activatorName_2 = this.activatorName(projectName);
    _builder.append(_activatorName_2, "\t");
    _builder.append("() {");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("/*");
    _builder.newLine();
    _builder.append("\t ");
    _builder.append("* (non-Javadoc)");
    _builder.newLine();
    _builder.append("\t ");
    _builder.append("* @see org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext)");
    _builder.newLine();
    _builder.append("\t ");
    _builder.append("*/");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("public void start(BundleContext context) throws Exception {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("super.start(context);");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("plugin = this;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("/*");
    _builder.newLine();
    _builder.append("\t ");
    _builder.append("* (non-Javadoc)");
    _builder.newLine();
    _builder.append("\t ");
    _builder.append("* @see org.eclipse.ui.plugin.AbstractUIPlugin#stop(org.osgi.framework.BundleContext)");
    _builder.newLine();
    _builder.append("\t ");
    _builder.append("*/");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("public void stop(BundleContext context) throws Exception {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("plugin = null;");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("super.stop(context);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("/**");
    _builder.newLine();
    _builder.append("\t ");
    _builder.append("* Returns the shared instance");
    _builder.newLine();
    _builder.append("\t ");
    _builder.append("*");
    _builder.newLine();
    _builder.append("\t ");
    _builder.append("* @return the shared instance");
    _builder.newLine();
    _builder.append("\t ");
    _builder.append("*/");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("public static ");
    CharSequence _activatorName_3 = this.activatorName(projectName);
    _builder.append(_activatorName_3, "\t");
    _builder.append(" getDefault() {");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("return plugin;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
}
